@@ -313,13 +313,13 @@ def load_data(connector, generate_batch, good_object_id, mapping_object, _replac
     generate_data_time = 0
 
     batch = generate_batch
-    total_batches = math.ceil((size * GB) / sys.getsizeof(batch[0]))
+    total_batches = math.ceil((size * GB) / float(sys.getsizeof(batch[0])))
     generate_data_time += batch[1]
     connector.load_data(batch[0], good_object_id, mapping_object, _replace, batch_number, total_batches)
 
     while batch_number <= total_batches:
         rows_loaded += len(batch[0])
-        print(f"Loaded {rows_loaded} rows out of {total_batches * batch_rows}")
+        print(f"Batch {batch_number}/{total_batches}: Loaded {rows_loaded} rows out of {total_batches * batch_rows}")
         batch_number += 1
         batch = generate_batch
         generate_data_time += batch[1]
